@@ -4,6 +4,11 @@
 # In[ ]:
 
 import pandas as pd
+
+def add_constant(df:pd.DataFrame) -> None:
+    df['constant'] = 1
+    
+    
 def add_day_of_week_dummies(df:pd.DataFrame, date_label:str=None):
     if date_label is None:
         dates_index = pd.to_datetime(df.index)
